@@ -1,9 +1,8 @@
 import contextlib
 import logging
 import re
-import warnings
 from dataclasses import replace
-from typing import Any, Awaitable, Dict, List, Optional, Set
+from typing import Any, Dict, List, Optional, Set
 
 import aiodocker
 import aiohttp
@@ -225,15 +224,6 @@ class Images(metaclass=NoPublicConstructor):
                 url = URL(resp.links["next"]["url"])
         return result
 
-    def ls(self, cluster_name: Optional[str] = None) -> Awaitable[List[RemoteImage]]:
-        warnings.warn(
-            "client.images.ls() ls is deprecated and scheduled for removal "
-            "in future Neuro SDK release, please use client.images.list() instead.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.list(cluster_name=cluster_name)
-
     def _validate_image_for_tags(self, image: RemoteImage) -> None:
         err = f"Invalid image `{image}`: "
         if image.tag is not None:
