@@ -12,7 +12,6 @@ from typing import (
     AsyncIterator,
     Dict,
     Iterable,
-    List,
     Mapping,
     Optional,
     Sequence,
@@ -119,7 +118,7 @@ class JobStatus(str, enum.Enum):
     def finished_items(cls) -> Set["JobStatus"]:
         return {item for item in cls.items() if item.is_finished}
 
-    __format__ = str.__format__
+    __format__ = str.__format__  # type: ignore[assignment]
     __str__ = str.__str__
 
 
@@ -542,13 +541,6 @@ class Jobs(metaclass=NoPublicConstructor):
             ret = await resp.json()
             return _job_description_from_api(ret, self._parse)
 
-    async def tags(self) -> List[str]:
-        url = self._config.api_url / "tags"
-        auth = await self._config._api_auth()
-        async with self._core.request("GET", url, auth=auth) as resp:
-            ret = await resp.json()
-            return ret["tags"]
-
     @asyncgeneratorcontextmanager
     async def top(
         self, id: str, *, cluster_name: Optional[str] = None
