@@ -7,7 +7,6 @@ import logging
 import os
 import re
 import time
-import warnings
 from dataclasses import dataclass
 from email.utils import parsedate_to_datetime
 from pathlib import Path
@@ -15,7 +14,6 @@ from stat import S_ISREG
 from typing import (
     AbstractSet,
     Any,
-    AsyncContextManager,
     AsyncIterator,
     Awaitable,
     Callable,
@@ -214,15 +212,6 @@ class Storage(metaclass=NoPublicConstructor):
                 for status in res["FileStatuses"]["FileStatus"]:
                     yield _file_status_from_api_ls(uri, status)
 
-    def ls(self, uri: URL) -> AsyncContextManager[AsyncIterator[FileStatus]]:
-        warnings.warn(
-            "client.storage.ls() ls is deprecated and scheduled for removal "
-            "in future Neuro SDK release, please use client.storage.list() instead.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.list(uri)
-
     @asyncgeneratorcontextmanager
     async def glob(self, uri: URL, *, dironly: bool = False) -> AsyncIterator[URL]:
         if not _has_magic(uri.path):
